/*****************************************************************
 KWin - the KDE window manager
 This file is part of the KDE project.

Copyright (C) 1999, 2000 Matthias Ettrich <ettrich@kde.org>
Copyright (C) 2003 Lubos Lunak <l.lunak@kde.org>

You can Freely distribute this program under the GNU General Public
License. See the file "COPYING" for the exact licensing terms.
******************************************************************/

#ifndef MAIN_H
#define MAIN_H

#include <kapplication.h>
#include "workspace.h"
#include "utils.h"

namespace KWin
{

class Application : public  KApplication
    {
    Q_OBJECT
    public:
        Application();
        ~Application();

    protected:
        bool x11EventFilter( XEvent * );
        bool notify( QObject* o, QEvent* e );
        static void crashHandler(int signal);
    private slots:
        void lostSelection();
        void resetCrashesCount();

    private:
        KWinSelectionOwner owner;
        static int crashes;
    };

} // namespace

#endif
